# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - Support Package

    This package collects small third party utilities in order
    to reduce the necessary steps in installing MoinMoin. Each
    source file is copyrighted by its respective author. I've done
    my best to assure those files are freely redistributable.

    Further details on the modules:

    cgitb
        from python 2.2 + patches (see XXX)

    @copyright: 2001-2004 by Jrgen Hermann <jh@web.de>
    @license: GNU GPL, see COPYING for details.
"""
